EllipticSigningKey

Enum EllipticSigningKey 

pub enum EllipticSigningKey {
    Prime256(SigningKey),
    Prime384(SigningKey),
    Prime521(SigningKey),
}
An elliptic curve signing key.

Variants



Prime256(SigningKey)

Using the P256 curve.



Prime384(SigningKey)

Using the P384 curve.



Prime521(SigningKey)

Using the P521 curve.

Implementations

Source

impl EllipticSigningKey

pub fn sign<D: Digest>(&self, message: &[u8]) -> Vec<u8>

Sign the message using this key and the digest algorithm.

Panics
  • If the digest algorithm produces a digest with a length that is less than half the field size of the curve.
  • Any other errors occur during signing.
pub fn verifying_key(&self) -> EllipticVerifyingKey

Get the verifying key for this signing key