pub struct Pss {
pub blinded: bool,
pub digest: Box<dyn DynDigest + Sync + Send>,
pub salt_len: Option<usize>,
}Expand description
Digital signatures using PSS padding.
Fields
blinded: boolCreate blinded signatures.
digest: Box<dyn DynDigest + Sync + Send>Digest type to use.
salt_len: Option<usize>Salt length. Required for signing, optional for verifying.
Implementations
Sourceimpl Pss
impl Pss
Sourcepub fn new<T>() -> Pss
pub fn new<T>() -> Pss
New PSS padding for the given digest. Digest output size is used as a salt length.
Sourcepub fn new_with_salt<T>(len: usize) -> Pss
pub fn new_with_salt<T>(len: usize) -> Pss
New PSS padding for the given digest with a salt value of the given length.
Sourcepub fn new_blinded<T>() -> Pss
pub fn new_blinded<T>() -> Pss
New PSS padding for blinded signatures (RSA-BSSA) for the given digest. Digest output size is used as a salt length.