pub struct RsaSigningKey(pub RsaPrivateKey);Expand description
An RSA signing key.
Tuple Fields
0: RsaPrivateKeyImplementations
Sourceimpl RsaSigningKey
impl RsaSigningKey
Sourcepub fn sign<S: SignatureScheme, D: Digest>(&self, message: &[u8]) -> Vec<u8> ⓘ
pub fn sign<S: SignatureScheme, D: Digest>(&self, message: &[u8]) -> Vec<u8> ⓘ
Sign the message using this key, the digest algorithm, and the signature scheme provided.
Panics
- If the provided signature scheme or digest would produce and invalid output.
Sourcepub fn verifying_key(&self) -> RsaVerifyingKey
pub fn verifying_key(&self) -> RsaVerifyingKey
Get the verifying key for this signing key.