pub struct Ed448SigningKey { /* private fields */ }Expand description
Signing key for Ed448
Implementations
Sourceimpl SigningKey
impl SigningKey
Sourcepub fn generate<R>(rng: &mut R) -> SigningKey
pub fn generate<R>(rng: &mut R) -> SigningKey
Generate a cryptographically random SigningKey.
Sourcepub fn to_bytes(&self) -> Array<u8, <Ed448 as CurveWithScalar>::ReprSize>
pub fn to_bytes(&self) -> Array<u8, <Ed448 as CurveWithScalar>::ReprSize>
Serialize this SigningKey as bytes.
Sourcepub fn as_bytes(&self) -> &Array<u8, <Ed448 as CurveWithScalar>::ReprSize>
pub fn as_bytes(&self) -> &Array<u8, <Ed448 as CurveWithScalar>::ReprSize>
Serialize this SigningKey as a byte reference.
Sourcepub fn to_scalar(&self) -> Scalar<Ed448>
pub fn to_scalar(&self) -> Scalar<Ed448>
Return the clamped EdwardsScalar for this SigningKey.
This is the scalar that is actually used for signing. Be warned, this is secret material that should be handled with care.
Sourcepub fn verifying_key(&self) -> VerifyingKey
pub fn verifying_key(&self) -> VerifyingKey
Get the VerifyingKey for this SigningKey.
Sourcepub fn with_context<'k, 'v>(
&'k self,
context: &'v [u8],
) -> Context<'k, 'v, SigningKey>
pub fn with_context<'k, 'v>( &'k self, context: &'v [u8], ) -> Context<'k, 'v, SigningKey>
Create a signing context that can be used for Ed448ph with
signature::DigestSigner
Sourcepub fn sign_raw(&self, message: &[u8]) -> Signature
pub fn sign_raw(&self, message: &[u8]) -> Signature
Sign a message with this SigningKey using the Ed448 algorithm
defined in RFC8032 5.2.
Sourcepub fn sign_ctx(
&self,
context: &[u8],
message: &[u8],
) -> Result<Signature, Error>
pub fn sign_ctx( &self, context: &[u8], message: &[u8], ) -> Result<Signature, Error>
Sign a message in the given context with this SigningKey using the Ed448ph algorithm
defined in RFC8032 5.2.
Sourcepub fn sign_prehashed<D>(
&self,
context: Option<&[u8]>,
prehashed_message: D,
) -> Result<Signature, Error>where
D: PreHash,
pub fn sign_prehashed<D>(
&self,
context: Option<&[u8]>,
prehashed_message: D,
) -> Result<Signature, Error>where
D: PreHash,
Sign a prehashed_message with this SigningKey using the
Ed448ph algorithm defined in RFC8032 5.2.