pub struct Ed448VerifyingKey { /* private fields */ }Expand description
Ed448 public key as defined in [RFC8032  5.2.5]
Implementations
Sourceimpl VerifyingKey
impl VerifyingKey
Sourcepub fn from_bytes(bytes: &[u8; 57]) -> Result<VerifyingKey, Error>
pub fn from_bytes(bytes: &[u8; 57]) -> Result<VerifyingKey, Error>
Construct a VerifyingKey from a slice of bytes.
Sourcepub fn with_context<'k, 'v>(
&'k self,
context: &'v [u8],
) -> Context<'k, 'v, VerifyingKey>
pub fn with_context<'k, 'v>( &'k self, context: &'v [u8], ) -> Context<'k, 'v, VerifyingKey>
Create a context for this verifying key that can be used with signature::DigestVerifier.
Sourcepub fn to_edwards(self) -> EdwardsPoint
pub fn to_edwards(self) -> EdwardsPoint
Return the verifying key in Edwards form.
Sourcepub fn verify_raw(
&self,
signature: &Signature,
message: &[u8],
) -> Result<(), Error>
pub fn verify_raw( &self, signature: &Signature, message: &[u8], ) -> Result<(), Error>
Verifies a signature on a message.
This is the “Ed448” mode of RFC 8032 (no pre-hashing, a
context is provided). This is equivalent to verify_ctx()
with an empty (zero-length) context.
Note: this function is not constant-time; it assumes that the public key and signature value are public data.
Sourcepub fn verify_ctx(
self,
sig: &Signature,
ctx: &[u8],
message: &[u8],
) -> Result<(), Error>
pub fn verify_ctx( self, sig: &Signature, ctx: &[u8], message: &[u8], ) -> Result<(), Error>
Verifies a signature on a message (with context).
This is the “Ed448” mode of RFC 8032 (no pre-hashing, a
context is provided). The context string MUST have length at most
255 bytes. Return value is Ok on a valid signature, Error
otherwise.
Note: this function is not constant-time; it assumes that the public key and signature value are public data.
Sourcepub fn verify_prehashed<D>(
self,
sig: &Signature,
ctx: Option<&[u8]>,
prehashed_message: D,
) -> Result<(), Error>where
D: PreHash,
pub fn verify_prehashed<D>(
self,
sig: &Signature,
ctx: Option<&[u8]>,
prehashed_message: D,
) -> Result<(), Error>where
D: PreHash,
Verifies a signature on a hashed message.
This is the “Ed448ph” mode of RFC 8032 (message is pre-hashed),
also known as “HashEdDSA on Curve448”. The hashed message prehashed_message
is provided (presumably, that hash value was obtained with
SHAKE256 and a 64-byte output; the caller does the hashing itself).
A context string ctx is
also provided; it MUST have length at most 255 bytes. Return
value is Ok on a valid signature, Error otherwise.
Note: this function is not constant-time; it assumes that the public key and signature value are public data.