pub trait VerifyingKey {
// Required methods
fn verifies(&self, signature: &[u8], message: &[u8]) -> bool;
fn raw_public_key(&self) -> Vec<u8> ⓘ;
fn from_raw_public_key(bytes: &[u8]) -> Option<Self>
where Self: Sized;
fn curve_oid(&self) -> ObjectIdentifier;
fn from_spki_der(der: &[u8]) -> Option<Self>
where Self: Sized;
}Expand description
A verifying key using EdDSA.
Required Methods
Sourcefn verifies(&self, signature: &[u8], message: &[u8]) -> bool
fn verifies(&self, signature: &[u8], message: &[u8]) -> bool
Returns if this key verifies the message to match the signature.
Sourcefn raw_public_key(&self) -> Vec<u8> ⓘ
fn raw_public_key(&self) -> Vec<u8> ⓘ
Get this key’s raw public key representation.
Sourcefn from_raw_public_key(bytes: &[u8]) -> Option<Self>where
Self: Sized,
fn from_raw_public_key(bytes: &[u8]) -> Option<Self>where
Self: Sized,
Create a verifying key from a raw public key.
Sourcefn curve_oid(&self) -> ObjectIdentifier
fn curve_oid(&self) -> ObjectIdentifier
Get the object identifier of the curve.
Sourcefn from_spki_der(der: &[u8]) -> Option<Self>where
Self: Sized,
fn from_spki_der(der: &[u8]) -> Option<Self>where
Self: Sized,
Create a new key from a subject public key info der.